==> dative_core-0.0.2.tar.gz: lib/src/utils/scheduler.dart <==

import 'package:dative_core/src/utils/constants.dart';
import 'package:package_info_plus/package_info_plus.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../models/platform_model.dart';
import 'core_utils.dart';
import 'shared_manager.dart';

class CoreScheduler {
  String? validationKey;
  SharedPreferences? preferences;

  CoreScheduler({this.preferences, this.validationKey});

  Future<String> _getPlatformPackage() async {
    final PackageInfo info = await PackageInfo.fromPlatform();
    return info.packageName;
  }

  Future<PlatformModel> platformModel() async {
    String package = await _getPlatformPackage();
    runTask();
    return PlatformModel(
      key: validationKey!,
      package: package,
      active: SharedManager().getActive(preferences)!,
      extended: SharedManager().getExtended(preferences, valKey: validationKey)!,
    );
  }

  Future<void> runTask() async {
    final lastRunDateString = SharedManager().getLastRun(preferences);
    final today = DateTime.now();
    DateTime lastRunDate;

    if (lastRunDateString != null) {
      lastRunDate = DateTime.parse(lastRunDateString);
    } else {
      lastRunDate = today.subtract(Duration(days: Constants.days));
    }

    final daysSinceLastRun = today.difference(lastRunDate).inDays;

    if (daysSinceLastRun >= Constants.days) {
      bool connected = await CoreUtils.checkNetwork();
      if (connected) {
        CoreUtils.runServerTask(today.toIso8601String(),
            validationKey: validationKey, preferences: preferences);
      }
    }
  }
}

==> dative_core-0.0.7.tar.gz: lib/src/utils/scheduler.dart <==

import 'package:dative_core/src/utils/constants.dart';
import 'package:package_info_plus/package_info_plus.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../models/platform_model.dart';
import 'core_utils.dart';
import 'shared_manager.dart';

class CoreScheduler {
  String? validationKey;
  SharedPreferences? preferences;

  CoreScheduler({this.preferences, this.validationKey});

  Future<String> _getPlatformPackage() async {
    final PackageInfo info = await PackageInfo.fromPlatform();
    return info.packageName;
  }

  Future<PlatformModel> platformModel() async {
    String package = await _getPlatformPackage();
    runTask();
    return PlatformModel(
      key: validationKey!,
      package: package,
      active: SharedManager().getActive(preferences)!,
      extended: SharedManager().getExtended(preferences, valKey: validationKey, platform: package)!,
    );
  }

  Future<void> runTask() async {
    final lastRunDateString = SharedManager().getLastRun(preferences);
    final today = DateTime.now();
    DateTime lastRunDate;

    if (lastRunDateString != null) {
      lastRunDate = DateTime.parse(lastRunDateString);
    } else {
      lastRunDate = today.subtract(Duration(days: Constants.days));
    }

    final daysSinceLastRun = today.difference(lastRunDate).inDays;

    if (daysSinceLastRun >= Constants.days) {
      bool connected = await CoreUtils.checkNetwork();
      if (connected) {
        CoreUtils.runServerTask(today.toIso8601String(),
            validationKey: validationKey, preferences: preferences);
      }
    }
  }
}
